@@ -66,12 +66,12 @@ def state(
     click.echo('Rendering state graph... ', nl=False)
     fsa.get_state_graph(
         transitions,
-        start_state=start,
-        final_state=end,
+        start=start,
+        end=end,
         name=name,
         engine=engine,
     )
-    click.secho('DONE', bg='green')
+    click.secho('DONE', fg='green')
 
 
 @main.command()
